<?php


namespace Controller;

use Service\Traits\TResponse;
use Zeedhi\Framework\DependencyInjection\InstanceManager;
use Util\Utilities;

class Organization
{
    
    use TResponse;
    
    public function organizationInactive(){
        ini_set("memory_limit", "1024M");
        ini_set('max_execution_time', '360000');
        set_time_limit(360000);
        /** @var \Service\Organization $organizationService */
        $organizationService = InstanceManager::getInstance()->getService('\Service\Organization');
        echo "Starting Inactive Organization!\n";
        $start = microtime(true);
        try{
            $organizationService->removeImportationOrganization();
            $organizationService->setAllOrganization();
            $organizationService->removeImportationWithoutDataSource();
        }catch (\Exception $e){
            echo $e->getMessage();
            throw $e;
        }
        $end = microtime(true);
        $total = $end - $start;
        echo("Done Inactive Organization!\n Tempo = $total\n");
    }
    public function findAllNext(\Zeedhi\Framework\DTO\Request $request, \Zeedhi\Framework\DTO\Response $response){
        try {
            $params = $request->getParameters();
            $filters = Utilities::parseParamNextToZmartFilterCriteria('allOrganizations', $params);
            $page = $filters->getPage();
            $pageSize = $filters->getPageSize();
            $orderBy = $filters->getOrderBy();
            $conditions = $filters->getConditions();
            $isPrimary =  \Util\Utilities::getValueInFilterDataSourceByName($conditions, 'IS_PRIMARY', true);

            /** @var \Service\Organization $organizationService */
            $organizationService = InstanceManager::getInstance()->getService('\Service\Organization');
            $organizations = $organizationService->findAll($conditions, $page, $pageSize, $orderBy, null, $isPrimary);
            $organizations = Utilities::parseDataSourceZeedhiNext($organizations);
            $this->sendResponse($organizations, 200);
            //  $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('allOrganizations', $organizations));
        } catch (\Exception $ex){
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function findClientsMongoNext(\Zeedhi\Framework\DTO\Request $request, \Zeedhi\Framework\DTO\Response $response){
        try {
            $params = $request->getParameters();
            Utilities::convertDynamicFilterToArray($params);
            $filters = \Util\Utilities::parseParamNextToZmartFilterCriteria('allOrganizations', $params);
            $conditions = $filters->getConditions();
            $room =  \Util\Utilities::getValueInFilterDataSourceByName($conditions, 'ROOM', true);
            $page = $filters->getPage();
            $pageSize = $filters->getPageSize();
            $limit = $page * $pageSize;
            $offset = ($page - 1) * $pageSize;

            /** @var \Service\Organization $organizationService */
            $organizationService = InstanceManager::getInstance()->getService('\Service\Organization');
            $organizations = $organizationService->findClientsMongo($conditions, $room, $limit, $offset);
            $total = $organizationService->countClientsMongo($conditions);
            $organizations = Utilities::parseDataSourceZeedhiNext($organizations, $total);
            $organizations["pagination"]["page"] = $page;
            $organizations["pagination"]["limit"] = $pageSize;
            $this->sendResponse($organizations, 200);
            // $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('allOrganizations', $organizations));
        } catch (\Exception $ex){
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function roomBalancingNext(\Zeedhi\Framework\DTO\Request $request, \Zeedhi\Framework\DTO\Response $response){
        try {
            $params = $request->getParameters();

            /** @var \Service\Organization $organizationService */
            $organizationService = InstanceManager::getInstance()->getService('\Service\Organization');
            $organizations = $organizationService->roomBalancing();
            $organizations = Utilities::parseDataSourceZeedhiNext($organizations);
            $this->sendResponse($organizations, 200);
        } catch (\Exception $ex){
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function clientsMongoSave(\Zeedhi\Framework\DTO\Request\DataSet $request, \Zeedhi\Framework\DTO\Response $response){
        try {
            $rows = $request->getDataSet()->getRows();
            /** @var \Service\Organization $organizationService */
            $organizationService = InstanceManager::getInstance()->getService('\Service\Organization');
            $organizations = $organizationService->clientsMongoSave($rows[0]);
            Utilities::setDataSetDefault($request,$response,$organizations);
        } catch (\Exception $ex){
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function execRoomBalancing(\Zeedhi\Framework\DTO\Request $request, \Zeedhi\Framework\DTO\Response $response){
        try {
            $params = $request->getParameters();
            $notRejeration = empty($params['NOT_REJERATION']) ? false : $params['NOT_REJERATION'];
            /** @var \Service\Organization $organizationService */
            $organizationService = InstanceManager::getInstance()->getService('\Service\Organization');
            $organizationService->execRoomBalancing($notRejeration);
        } catch (\Exception $ex){
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($ex->getMessage(), $ex->getCode()));
        }
    }
}